@@ -1,6 +1,7 @@
 import time
 from threading import Timer
 import atexit
+import json
 
 from modular_client import ModularClient
 
@@ -25,7 +26,7 @@ DEBUG = False
 class LickportArrayInterface():
     '''
     '''
-    _CHECK_DATA_PERIOD = 1.0
+    _CHECK_DATA_PERIOD = 2.0
     def __init__(self,*args,**kwargs):
         if 'debug' in kwargs:
             self.debug = kwargs['debug']
@@ -35,19 +36,25 @@ class LickportArrayInterface():
         atexit.register(self._exit)
         self.controller = ModularClient()
         self.controller.set_time(int(time.time()))
+        self.controller.calibrate_lick_sensor()
         self.data = []
 
-    def start_check_data_timer(self):
-        self._check_data_timer = Timer(self._CHECK_DATA_PERIOD,self._check_data)
+    def start_check_data_timer(self,period=None):
+        if period:
+            self._check_data_timer = Timer(period,self._check_data)
+        else:
+            self._check_data_timer = Timer(self._CHECK_DATA_PERIOD,self._check_data)
         self._check_data_timer.start()
 
     def _check_data(self):
-        self.start_check_data_timer()
         data = self.controller.get_and_clear_lick_data()
         if len(data) > 0:
             for datum in data:
                 print(datum)
             self.data.extend(data)
+            with open('data.txt', 'w') as outfile:
+                json.dump(self.data, outfile)
+        self.start_check_data_timer()
 
     def _exit(self):
         try:
@@ -57,8 +64,9 @@ class LickportArrayInterface():
 
 def main(args=None):
     debug = False
+    period = 5.0
     lai = LickportArrayInterface(debug=debug)
-    lai.start_check_data_timer()
+    lai.start_check_data_timer(period=period)
 
 # -----------------------------------------------------------------------------------------
 if __name__ == '__main__':
